@@ -53,7 +53,7 @@ class Queue(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["QueueProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[QueueProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
             ) -> None:
                 ...
@@ -269,7 +269,7 @@ class RosQueue(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["RosQueueProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[RosQueueProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: builtins.bool,
             ) -> None:
                 ...
@@ -724,7 +724,7 @@ class RosSubscription(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["RosSubscriptionProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[RosSubscriptionProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: builtins.bool,
             ) -> None:
                 ...
@@ -1128,7 +1128,7 @@ class RosTopic(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["RosTopicProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[RosTopicProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: builtins.bool,
             ) -> None:
                 ...
@@ -1399,7 +1399,7 @@ class Subscription(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["SubscriptionProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[SubscriptionProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
             ) -> None:
                 ...
@@ -1591,7 +1591,7 @@ class Topic(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["TopicProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[TopicProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
             ) -> None:
                 ...
